<?php

namespace App\Http\Controllers\Gallery;

use App\Facade\UserConfig;
use App\Helpers\DbHelper;
use App\Http\Controllers\Controller;
use App\PhotoComment;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Auth;

class PhotoCommentController extends Controller
{
    public function store(Request $request, $albumUrlAlias, $photoFilename)
    {
        $album = DbHelper::getAlbumByPath($albumUrlAlias);
        if (is_null($album))
        {
            App::abort(404);
            return null;
        }

        $this->authorizeForUser($this->getUser(), 'view', $album);

        $photo = PhotoController::loadPhotoByAlbumAndFilename($album, $photoFilename);

        if (!UserConfig::get('allow_photo_comments'))
        {
            // Not allowed to post comments - redirect back to URL
            return redirect($photo->url());
        }

        $comment = new PhotoComment();
        $comment->photo_id = $photo->id;
        $comment->fill($request->only(['commentor_email', 'commentor_name', 'comment_text']));

        $user = $this->getUser();
        if (!is_null($user) && !$user->isAnonymous())
        {
            $comment->created_user_id = $user->id;
        }

        $comment->save();

        $request->getSession()->flash('success', trans('gallery.photo_comment_posted_successfully'));

        return redirect($photo->url());
    }
}